%global packname Rcpp

%global __suggests_exclude ^R\\((pkgKitten|rbenchmark|tinytest)\\)

Name:		R-%{packname}
Version:	1.0.14
Release:	%mkrel 1
Summary:	Seamless R and C++ Integration
Group:          Sciences/Mathematics

#		The following three files uses the Boost Software License:
#		- Rcpp/inst/include/Rcpp/utils/tinyformat/tinyformat.h
#		- Rcpp/inst/include/Rcpp/macros/config.hpp
#		- Rcpp/inst/include/Rcpp/macros/cat.hpp
License:	GPLv2+ and Boost
URL:		https://cran.r-project.org/package=%{packname}
Source0:	%{url}&version=%{version}#/%{packname}_%{version}.tar.gz

BuildRequires:	gcc-c++
BuildRequires:	R-base
BuildRequires:	dos2unix
BuildRequires:	R-rpm-macros
BuildRequires:	texinfo-tex

%description
The Rcpp package provides R functions as well as C++ classes which
offer a seamless integration of R and C++. Many R data types and
objects can be mapped back and forth to C++ equivalents which
facilitates both writing of new code as well as easier integration of
third-party libraries.
Documentation about Rcpp is provided by several vignettes included in
this package, via the Rcpp Gallery site at http://gallery.rcpp.org,
the paper by Eddelbuettel and Francois (2011, JSS), and the book by
Eddelbuettel (2013, Springer).
See citation("Rcpp") for details on the last two.

%package devel
Summary:	Rcpp Development Files
Requires:	%{name} = %{version}-%{release}
Requires:	R-base

%description devel
Header files for Rcpp.

%package examples
Summary:	Rcpp Examples
Requires:	%{name} = %{version}-%{release}

%description examples
Examples for using Rcpp.

%prep
%setup -q -c

dos2unix -k \
    %{packname}/inst/tinytest/cpp/InternalFunction.cpp \
    %{packname}/inst/tinytest/cpp/InternalFunctionCPP11.cpp

%build

%install
mkdir -p %{buildroot}%{_libdir}/R/library
%{_bindir}/R CMD INSTALL -l %{buildroot}%{_libdir}/R/library %{packname}
test -d %{packname}/src && (cd %{packname}/src; rm -f *.o *.so)
rm -rf %{buildroot}%{_libdir}/R/library/R.css
rm -rf %{buildroot}%{_libdir}/R/library/%{packname}/tinytest

sed 's!/bin/env Rscript!/usr/bin/Rscript!' \
    -i %{buildroot}%{_libdir}/R/library/%{packname}/discovery/cxx0x.R
chmod 755 %{buildroot}%{_libdir}/R/library/%{packname}/discovery/cxx0x.R

for f in ConvolveBenchmarks/overhead.r ConvolveBenchmarks/overhead.sh \
	 Misc/ifelseLooped.r Misc/newFib.r OpenMP/OpenMPandInline.r ; do
    chmod 755 %{buildroot}%{_libdir}/R/library/%{packname}/examples/$f
done

for f in `find %{buildroot}%{_libdir}/R/library/%{packname}/examples -type f` ; do
    grep -q '/usr/bin/env r' $f && sed 's!/usr/bin/env r!/usr/bin/R!' -i $f
done

%check
_R_CHECK_FORCE_SUGGESTS_=0 %{_bindir}/R CMD check %{packname}

%files
%dir %{_libdir}/R/library/%{packname}
%doc %{_libdir}/R/library/%{packname}/NEWS.Rd
%doc %{_libdir}/R/library/%{packname}/announce
%doc %{_libdir}/R/library/%{packname}/bib
%doc %{_libdir}/R/library/%{packname}/doc
%doc %{_libdir}/R/library/%{packname}/html
%{_libdir}/R/library/%{packname}/CITATION
%{_libdir}/R/library/%{packname}/DESCRIPTION
%{_libdir}/R/library/%{packname}/INDEX
%{_libdir}/R/library/%{packname}/NAMESPACE
%{_libdir}/R/library/%{packname}/Meta
%{_libdir}/R/library/%{packname}/R
%{_libdir}/R/library/%{packname}/discovery
%{_libdir}/R/library/%{packname}/help
%{_libdir}/R/library/%{packname}/libs
%{_libdir}/R/library/%{packname}/prompt
%{_libdir}/R/library/%{packname}/skeleton

%files devel
%{_libdir}/R/library/%{packname}/include

%files examples
%{_libdir}/R/library/%{packname}/examples


%changelog
* Sat Jan 25 2025 daviddavid <daviddavid> 1.0.14-1.mga10
+ Revision: 2142287
- new version: 1.0.14

* Tue Aug 27 2024 papoteur <papoteur> 1.0.13-2.mga10
+ Revision: 2091749
- rebuild for R-base 4.4.1

* Sun Aug 25 2024 neoclust <neoclust> 1.0.13-1.mga10
+ Revision: 2091085
- New version 1.0.13

* Tue Aug 09 2022 neoclust <neoclust> 1.0.9-1.mga9
+ Revision: 1876388
- New version 1.0.9

* Sat Apr 02 2022 umeabot <umeabot> 1.0.7-2.mga9
+ Revision: 1840775
- Mageia 9 Mass Rebuild

* Wed Oct 20 2021 joequant <joequant> 1.0.7-1.mga9
+ Revision: 1752257
- upgrade to 1.0.7

* Thu Jul 01 2021 joequant <joequant> 1.0.6-1.mga9
+ Revision: 1734449
- update to 1.0.6

* Wed Nov 18 2020 joequant <joequant> 1.0.5-2.mga8
+ Revision: 1647032
- update to R 4.0.3
- rebuild for 4.0.3

* Fri May 08 2020 joequant <joequant> 1.0.4-3.mga8
+ Revision: 1581694
- redo deps
- change bin to R

* Wed May 06 2020 joequant <joequant> 1.0.4-2.mga8
+ Revision: 1580716
- fix deps
- fix up deps

* Wed Apr 22 2020 joequant <joequant> 1.0.4-1.mga8
+ Revision: 1570972
- add texinfo-tex
- change group
- add group
- imported package R-Rcpp

